<template>
  <div class="info-security-man">
    <div class="header">
      <div class="title">
        <i class="icon"></i>
        <div class="info">
          <span class="name">{{ title }}</span>
        </div>
      </div>
    </div>
    <div class="content">
      <div class="employee-box" v-for="(item, index) in data" :key="index">
        <avatar :size="40">
          <div class="per-name">
            {{ item.name.slice(-2) }}
          </div>
        </avatar>
        <div class="info">
          <div class="title">{{ item.name }}</div>
          <div class="detail">
            <span class="label">联系方式：</span>
            <span v-if="!item.concatVisible" class="value">{{ item.contactHide }}</span>
            <span v-if="item.concatVisible" class="value">{{ item.contact }}</span>
            <span class="visible" @click.stop="item.concatVisible = !item.concatVisible">
              {{ item.concatVisible ? "隐藏" : "显示" }}
            </span>
          </div>
          <div class="detail">
            <span class="label">在岗情况：</span>
            <span class="value">{{ item.dutyStatusText }}</span>
          </div>
        </div>
      </div>
    </div>
  </div>
</template>

<script>
import Avatar from "@components/avatar.vue";

export default {
  name: "infoSecurityMan",
  components: { Avatar },
  props: {
    data: Array,
    station: Object,
  },
  computed: {
    title() {
      return `${this.station?.name}`;
    },
  },
};
</script>

<style scoped lang="less">
.info-security-man {
  .header {
    width: 100%;
    height: 72px;
    background: #ffffff;
    padding: 0 20px;
    box-sizing: border-box;
    display: flex;
    align-items: center;
    justify-content: space-between;
    .title {
      height: 100%;
      display: flex;
      align-items: center;
      .icon {
        display: block;
        width: 36px;
        height: 36px;
        background: url("~@/assets/images/mapSearch/驻勤点备份.png") no-repeat;
        background-size: 100% 100%;
      }
      .info {
        margin-left: 8px;
        .name {
          font-size: 14px;
          font-family: PingFang SC-Medium, PingFang SC, serif;
          font-weight: 500;
          color: #303133;
          line-height: 22px;
        }
      }
    }
  }
  .content {
    height: 394px;
    width: 100%;
    overflow-x: hidden;
    overflow-y: auto;
    padding: 0 20px;
    box-sizing: border-box;
    .employee-box {
      width: 100%;
      height: 94px;
      border-bottom: 1px solid #d8d8d8;
      display: flex;
      flex-direction: row;
      padding: 12px 0;
      justify-content: space-between;
      position: relative;
      .per-name {
        height: 40px;
        width: 40px;
        background: #0e71ff;
        color: #fff;
        font-size: 12px;
        display: flex;
        align-items: center;
        justify-content: center;
      }
      .info {
        width: 279px;
        //padding: 12px 20px;
        .title {
          font-size: 14px;
          font-family: PingFang SC-Medium, PingFang SC, serif;
          font-weight: 500;
          color: #303133;
          line-height: 22px;
          margin-bottom: 2px;
        }
        .detail {
          width: 100%;
          display: flex;
          align-items: center;
          margin-bottom: 10px;
          &:last-child {
            margin-bottom: 0;
          }
          .label {
            font-size: 12px;
            font-family: PingFang SC-Regular, PingFang SC, serif;
            font-weight: 400;
            color: #909399;
          }
          .value {
            font-size: 12px;
            font-family: PingFang SC-Regular, PingFang SC;
            font-weight: 400;
            color: #303133;
            &-link {
              font-size: 12px;
              font-family: PingFang SC-Regular, PingFang SC;
              font-weight: 400;
              color: #0f71ff;
              text-decoration: underline;
            }
          }
          .visible {
            font-size: 12px;
            font-family: PingFang SC-Regular, PingFang SC;
            font-weight: 400;
            color: #0f71ff;
            margin-left: 2px;
          }
        }
      }
    }
  }
}
</style>
